#!/bin/bash
# packager           : Frederic Boulet <bipbip> bipbiponlinux~AT~gmail.com
# original build script from Sebastian Jauch
# source location    : http://tilda.sourceforge.net/wiki/index.php/Main_Page
# last revised       : 29.4.2010

softname='dia'
softversion='0.97.1'
packageversion='64.1'

arch='i486'
cpu='i686'

# log ;)
(

# parameters needed for the build process
buildir=$(pwd)
srcpkg="$buildir/$softname-$softversion.tar.bz2"
src="$buildir/$softname-$softversion"
package="$softname-$softversion-$arch-$packageversion"
dest="$buildir/$package"
source=ftp://ftp.gnome.org/pub/gnome/sources/dia//$softname-$softversion.tar.bz2

# prepare the build result directory
dest="$buildir/$package"
rm -rf $dest
mkdir -p $dest
mkdir -p $dest/install
mkdir -p $dest/usr/doc/$softname-$softversion
mkdir -p $dest/usr/share/icons/hicolor/48x48/apps/
mkdir -p $dest/usr/share/applications
mkdir -p $dest/usr/man
mkdir -p $dest/usr/share/$softname
mkdir -p $dest/usr/src/$softname-$softversion

# Slack-desc
cat <<EOF > $dest/install/slack-desc
   |-----handy-ruler------------------------------------------------------|
dia: Dia is a diagram drawing application
dia:
dia: Dia is designed to be much like the commercial
dia: Windows program 'Visio'. It can be used to draw
dia: many different kinds of diagrams.
dia:
dia:
dia:
dia:
dia:
EOF

# check if source is present
if [ -f $softname-$softversion.tar.bz2 ]; then
	echo "Source file already here, no need to download";
else
 	echo "Downloading source"
	wget -c --no-check-certificate $source
fi

# extract the source code
cd $buildir
tar xvf $srcpkg
cd $src

# build

    export CFLAGS="-O2 -march=$arch -mtune=$cpu"
    export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"

    ./configure \
      --prefix=/usr \
      --mandir=/usr/man \
      --docdir=/usr/doc/$softname-$softversion \
      --htmldir=/usr/doc/$softname-$softversion \
      --with-python \
      --with-swig \
      --enable-libemf \
      --program-prefix="" \
      --program-suffix="" \
      --build=$arch-slackware-linux \
      --host=$arch-slackware-linux \
      --target=$arch-slackware-linux

    make
    make install DESTDIR=$dest

# update mime info
cat << "EOF" > $dest/install/doinst.sh
# update the mime desktop database
if [ -x usr/bin/update-desktop-database ]; then
     usr/bin/update-desktop-database -q
fi
# update the mime database
if [ -x usr/bin/update-mime-database ]; then
     usr/bin/update-mime-database usr/share/mime > /dev/null 2>&1
fi
EOF

# add 'default' files
    cp -a \
      AUTHORS ChangeLog COPYING INSTALL NEWS MAINTAINERS KNOWN* README TODO THANKS RELEASE* \
      $dest/usr/doc/$softname-$softversion

# Strip
( cd $dest
  find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)

# compress man pages
( mv $dest/usr/share/man/fr $dest/usr/man/fr
  cd $dest/usr/man
  find . -name "*.?" | xargs gzip -9
)

# ZenBuild
cp $buildir/build-$softname.sh $dest/usr/src/$softname-$softversion

# set target permissions
chown -R root:root $dest

cd $dest
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

# real packaging work
cd $dest
makepkg -l y -c n $dest.txz

# md5sum signature
cd $buildir
md5sum $package.txz > $package.md5

# .dep
cd $buildir
echo -e "atk,cairo,cxxlibs,gcc-g++,expat,fontconfig,freetype,gcc,glib2,\
gtk+2,libX11,libXau,libXcomposite,libXcursor,libXdamage,libXdmcp,libXext,\
libXfixes,libXi,libXinerama,libXrandr,libXrender,libart_lgpl,libpng,libxcb,\
libxml2,libxslt,pango,pixman,swig,zlib" > $package.dep

# generate source file
echo http://zenwalk.pinguix.com/user-accounts/bip/EXTRA/xap/tilda/source/build-tilda.sh > $package.src
echo $source >> $package.src

# erase
rm -rf $src
rm -rf $dest

# log ;)
) 2>&1 | tee "$softname-$softversion-build.log"
